"""Empty values of various types"""

none = None
string = ""
integer = 0
real = 0.0
